# -*- coding:utf-8 -*-
import os
import pkg_resources

from abu.admin import Interface

class Admin(Interface):
    def version(self):
        return '0.0.1'
    
    def init(self, path):
        with open(os.path.join(path, 'README'), 'w') as readme:
            readme.write(pkg_resources.resource_string('read_and_display',
                'config_templates/README.template'))





# -*- coding:utf-8 -*-

class Interface(object):
    def version(self):
        raise NotImplementedError

    def init(self, path):
        raise NotImplementedError

    def backup(self, path, backup_file):
        raise NotImplementedError

    def restore(self, path, backup_file):
        raise NotImplementedError

    def upgrade(self, path, old_version):
        raise NotImplementedError




from setuptools import setup, find_packages
import sys, os

version = '0.1.0'

setup(name='read_and_display',
      version=version,
      description="",
      long_description="""\
""",
      classifiers=[], # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      keywords='',
      author='LaiYonghao',
      author_email='mail@laiyonghao.com',
      url='',
      license='mit',
      packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),

      include_package_data=True,
      zip_safe=False,
      install_requires=[
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      # -*- Entry points: -*-
      [console_scripts]
      read_and_display = read_and_display.main:main
      [abu.admin]
      read_and_display = read_and_display.admin:Admin
      """,
      )



from setuptools import setup, find_packages

version = '0.1.1'

setup(name='abu.admin',
      version=version,
      description='',
      long_description="""\
""",
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Framework :: Zope2",
        "Framework :: Zope3",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='',
      author='LaiYonghao',
      author_email='mail@laiyonghao.com',
      url='http://code.google.com/p/abu-admin',
      license='MIT',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['abu'],
      include_package_data=True,
      test_suite='nose.collector',
      test_requires=['Nose'],  
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
          'argparse',
      ],
      entry_points="""
      # -*- Entry points: -*-
      [console_scripts]
      abu.admin = abu.admin.main:main
      """,
      )




#!/usr/bin/env python

import os
import sys
import itertools
import ConfigParser
import pkg_resources
import argparse

rc_name = '__ABU_ADMIN_RC___'

eps = pkg_resources.iter_entry_points('abu.admin')

def check_app(name):
    for ep in eps:
        if ep.name == name:
            return True
    return False

def check_path(path):
    return os.path.isdir(path)

def check_rc(path):
    return os.path.exists(path)

def do_list():
    if not eps:
       return
    for no, ep in zip(itertools.count(1), eps):
       print "%s : %s\n" % (no, ep.name)

def do_init():
    name, path = sys.argv[2], sys.argv[3]
    if not check_app(name):
        print '%s is not abu.admin application.' % name
        return
    if not check_path(path):
        print '%s is not a derectory.' % path
        return
    rc_path = os.path.join(path, rc_name)
    if check_rc(rc_path):
        print '%s file already exists, can\'t init env in %s.' % (rc_name, path)
        return
    impl_cls = pkg_resources.load_entry_point(name, 'abu.admin', name)
    impl = impl_cls()
    with open(rc_path, 'w') as rc:
        sec = 'abu.admin'
        cfg = ConfigParser.ConfigParser()
        cfg.add_section(sec)
        cfg.set(sec, 'app', name)
        cfg.set(sec, 'version', impl.version())
        cfg.write(rc)
    try:
        impl.init(path)
    except Exception:
        os.remove(rc_path)
        raise

def do_backup():
    print 'this command is unsupported yet.'

def do_restore():
    print 'this command is unsupported yet.'

def do_upgrade():
    print 'this command is unsupported yet.'

def print_basic_usage():
    print 'run "abu.admin help" for usage.'

def print_help():
    if len(sys.argv) > 2:
        print_subcommand_help()
        return
    print 'abu.admin <subcommand> [options] [args]'
    print 'run "abu.admin help <subcommand>" for usage of subcommand.'
    print '\n    '.join(['available subcommands:',
        'init',
        'backup',
        'restore',
        'upgrade',

        'list',
        'help',
        ])

def print_subcommand_help():
    subcmd = sys.argv[2]
    if subcmd == 'init':
        print 'abu.admin init <application> </path/to/instance>'
    elif subcmd == 'backup':
        print 'this command is unsupported yet.'
    elif subcmd == 'restore':
        print 'this command is unsupported yet.'
    elif subcmd == 'list':
        print 'list all applications supported abu.abmin.'
        print 'abu.admin list'
    elif subcmd == 'upgrade':
        print 'this command is unsupported yet.'
    else:
        print 'invalid subcommand.'
        print_basic_usage()
        return

def main():
    if len(sys.argv) < 2:
        print_basic_usage()
        sys.exit(1)
    cmd = sys.argv[1]
    if cmd == 'help':
        print_help()
    elif cmd == 'list':
        do_list()
    elif cmd == 'init':
        if len(sys.argv) != 4:
            print_help()
            sys.exit(1)
        do_init()
    elif cmd == 'backup':
        do_backup()
    elif cmd == 'restore':
        do_restore()
    elif cmd == 'upgrade':
        do_upgrade()
    else:
        print 'subcommand(%s) is not found.' % cmd
        print_basic_usage()
        sys.exit(1)

